.. _examples:

.. In order to build the examples, you'll need (on Debian)
    sudo apt-get install python-tables python-matplotib python-vtk

========
Examples
========

.. toctree::
   :maxdepth: 2

   note_about_examples
   examples_built/nii_2_tracks
   examples_built/find_correspondence
   examples_built/aniso_vox_2_isotropic
   examples_built/visualize_crossings
   examples_built/tractography_clustering
   examples_built/file_formats
